#!/usr/bin/env bash
#set -x
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2016  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################
# Verify input
#TODO:need detailed usage statement

printusage() {
echo "usage: FP1DB2Update.sh DB2_ADMIN DB2_PASS DB2INSTALLDIR DBNAME WAS_HOME DB2_Service_Name
  where
  DB2_ADMIN is the Database Instance Owner specified during the install
  DB2_PASS is the password of the database instance owner
  DB2INSTALLDIR is the DB2 install directory Example /opt/IBM/DB2SKLMV40 - In case of non root install, its instance home directory including sqllib Example /home/testuser/sqllib   
  DBNAME is the database name, default is SKLMDB
  WAS_HOME is path to WAS_HOME folder.
  DB2_Service_Name DB2 service name - optional"
exit 1
}



performDBChanges() {
	if [ "$username" != "$DB2ADMIN" ]; then
		cp $HOME/sklm40properties/scripts/tklmsql-fp.db2 /tmp >> $HOME/sklm40properties/scripts/DB2update.output
		su - $DB2ADMIN -c "${INSTALLDIR}/bin/db2 connect to $DBNAME user $DB2ADMIN using '$DB2PASS'" >> $HOME/sklm40properties/scripts/DB2update.output
		su - $DB2ADMIN -c "${INSTALLDIR}/bin/db2 connect to $DBNAME user $DB2ADMIN using '$DB2PASS' && ${INSTALLDIR}/bin/db2 -td# -s -f  /tmp/tklmsql-fp.db2" >> $HOME/sklm40properties/scripts/DB2update.output
		RC=$?
		rm -f /tmp/tklmsql-fp.db2
	else
		#chmod -R 775 $HOME/sklm40properties
		#. ${HOME}/.profile
		db2 "connect to $DBNAME user $DB2ADMIN using '$DB2PASS'" >> $HOME/sklm40properties/scripts/DB2update.output
		db2 -td# -s -f  "$HOME/sklm40properties/scripts/tklmsql-fp.db2" >>  $HOME/sklm40properties/scripts/DB2update.output
		RC=$?
	fi
}


   export DB2ADMIN="$1"
   export DB2PASS="$2"
   export INSTALLDIR="$3"
   export DBNAME="$4"
   export WAS_HOME=$5
   export DB2_SRV_NAME=$6
   export MASTERTYPE=
   
   echo Input variables: >>  $HOME/sklm40properties/scripts/DB2update.output
   echo DB2ADMIN=$DB2ADMIN >> $HOME/sklm40properties/scripts/DB2update.output
   echo INSTALLDIR=$INSTALLDIR >> $HOME/sklm40properties/scripts/DB2update.output
   echo DBNAME=$DBNAME >> $HOME/sklm40properties/scripts/DB2update.output
   echo WAS_HOME=$WAS_HOME >> $HOME/sklm40properties/scripts/DB2update.output
   

if [ "$DB2ADMIN" =  "" ]; then
   printusage
fi

if [ "$DB2PASS" =  "" ]; then
   printusage
fi
if
[ "$INSTALLDIR" = "" ]; then
   printusage
fi
if
[ "$DBNAME" = "" ]; then
   printusage
fi

if [ "${WAS_HOME}" = "" ]; then
	echo WAS_HOME path ${WAS_HOME} does not exist.
	exit 1 
fi




#. $WAS_HOME/products/sklm/config/MMConfig.properties
file="$WAS_HOME/products/sklm/config/MMConfig.properties"
  while IFS="=" read -r key value; do
    if [ "$key" = "multimasterRole" ]; then
      multimasterRole="$value"
    fi
  done < "$file"

username=$(whoami)
echo user : $username >> $HOME/sklm40properties/scripts/DB2update.output

if [ ! -d "${INSTALLDIR}" ]; then
 	echo "Error:" $INSTALLDIR " does not exist"
  	RC=-10
fi



if [ "$multimasterRole" = "STANDBY" ]; then
	echo Skipping database changes as role is STANDBY.
else
	#Perform db2 changes for PRIMARY and STANDALONE (non STANDBY)
	echo Executing database changes as role is not STANDBY.
	performDBChanges
fi

if [ $RC -eq 0 ]; then
  echo "Update of DB2 instance is complete."
fi
exit $RC
