#! /bin/bash
logfilepath=/tmp/sklmInstaller.log
servicedirpath=/etc/systemd/system

printusage() {
echo "*************************************************************
Usage: 
    ./sklmservice.sh DB2_SVC_NAME DB2_HOME DB2_USERNAME DB2_INSTANCE_NAME WAS_HOME SKLM_PROPERTIES_DIR_NAME SKLM_LOCATION
    where
    DB2_SVC_NAME is the directory where Installation manager for SKLM is installed.
    DB2_HOME is DB2 user home directory
    DB2_USERNAME is DB2 admin user 
    DB2_INSTANCE_NAME is Db2 Instance name
    WAS_HOME is the directory where WebSphere Application Server(WAS) for SKLM is installed.
    SKLM_PROPERTIES_DIR_NAME is directory name of SKLM properties under user home.
	SKLM_LOCATION is location where SKLM is installed 
	
Example : ./sklmservice.sh 	db2c_sklmdbxx
							/home/sklmdbxx
							sklmdbxx
							sklmdbxx_inst
							/opt/IBM/WebSphere/AppServer 
							sklmxxproperties
							/opt/IBM/SKLMVXX	  
							
*************************************************************"
exit 1
}



if [ $# -ne 7 ]; then
	printusage
else
	db2servicename=$1
	db2home=$2
	db2username=$3
	db2instancename=$4
	washome=$5
	sklmPropertiesDir=$6
	sklmLocation=$7   
fi


if [ "$db2servicename" = "" ]; then
   printusage
fi
if [ "$db2home" = "" ]; then
   printusage
fi
if [ "$db2username" = "" ]; then
   printusage
fi
if [ "$db2instancename" = "" ]; then
   printusage
fi
if [ "$washome" = "" ]; then
   printusage
fi
if [ "$sklmPropertiesDir" = "" ]; then
   printusage
fi
if [ "$sklmLocation" =  "" ]; then
   printusage
fi


if [ ! -d $washome ]
then
echo "Check if the parameter WAS_HOME is set to the valid WAS directory."
exit 1
fi

if [ ! -f  $washome/bin/stopServer.sh ]
then
echo "Check if the parameter WAS_HOME is set to the valid WAS directory."
exit 1
fi



db2servicefullpath=${servicedirpath}/${db2servicename}

echo db2servicename=$db2servicename >> $logfilepath
echo db2home=$db2home >> $logfilepath
echo db2servicefullpath=$db2servicefullpath >> $logfilepath


if [ -d ${servicedirpath} ]; then
	systemctl stop db2fmcd  >> $logfilepath
	systemctl disable db2fmcd  >> $logfilepath
	#Remove DB2 service if already exist
	if [ -f ${db2servicefullpath} ]; then
		systemctl disable ${db2servicename}
		rm -f ${db2servicefullpath}
		systemctl daemon-reload
		systemctl reset-failed
	fi

	#Creating DB2 service file.
	echo creating DB2 service file ${db2servicefullpath} >> $logfilepath
	echo [Unit] > ${db2servicefullpath}
	echo Description=DB2SKLMV40 >> ${db2servicefullpath}
	echo  >> ${db2servicefullpath}
	echo [Service] >> ${db2servicefullpath}
	echo Type=forking  >> ${db2servicefullpath}
	echo User=${db2username} >> ${db2servicefullpath}
	#echo #Group=${db2username} >> ${db2servicefullpath}
	echo ExecStart=${db2home}/sqllib/adm/db2start >> ${db2servicefullpath}
	echo ExecStop=${db2home}/sqllib/adm/db2stop force >> ${db2servicefullpath}
	echo Environment="DB2INSTANCE=${db2instancename}" >> ${db2servicefullpath}
	#echo ExecStart=${db2home}/sqllib/bin/db2fmd >> ${db2servicefullpath}
	echo Restart=on-abort >> ${db2servicefullpath}
	echo  >> ${db2servicefullpath}
	echo [Install] >> ${db2servicefullpath}
	echo WantedBy=default.target >> ${db2servicefullpath}
	
	echo enabling DB2 service "systemctl enable ${db2servicename}" >> $logfilepath
	chmod +x  ${db2servicefullpath}
	systemctl daemon-reload
	systemctl enable ${db2servicename}
	retcode=$?
	echo Enable ${db2servicename} return code : $retcode >> $logfilepath
	#Service validation
	su - ${db2username} -c "db2stop force"
	systemctl start ${db2servicename}
	retcode=$?
	echo Start ${db2servicename} return code : $retcode >> $logfilepath
	
	

fi 

chown -R ${db2username} ${washome}
chmod -R 750 ${washome}/bin
chown -R ${db2username} ${sklmLocation}
nruserhome=$(cat /etc/passwd | grep ${db2username} | cut -d ":" -f6)
#mv ${HOME}/${sklmPropertiesDir}  ${nruserhome}
chown -R ${db2username} ${nruserhome}/${sklmPropertiesDir}
#su - ${db2username} -c "${washome}/bin/startServer.sh server1"

exit 0
